@@ -24,7 +24,7 @@ REGIONS = {u'ad': u'\u0531\u0576\u0564\u0578\u057c\u057c\u0561',
  u'bh': u'\u0532\u0561\u0570\u0580\u0561\u056b\u0576',
  u'bi': u'\u0532\u0578\u0582\u0580\u0578\u0582\u0576\u0564\u056b',
  u'bj': u'\u0532\u0565\u0576\u056b\u0576',
- u'bl': u'\u054d\u0561\u056b\u0576\u0569 \u0532\u0561\u057c\u0569\\u00e9lemy',
+ u'bl': u'\u054d\u0561\u056b\u0576\u0569 \u0532\u0561\u057c\u0569\xe9lemy',
  u'bm': u'\u0532\u0565\u0580\u0574\u0578\u0582\u0564\u0561',
  u'bn': u'\u0532\u0580\u0578\u0582\u0576\u0565\u056b \u054d\u0578\u0582\u056c\u0569\u0561\u0576\u0578\u0582\u0569\u0575\u0578\u0582\u0576',
  u'bo': u'\u0532\u0578\u056c\u056b\u057e\u056b\u0561',
